/*
 *      callbacks.c
 *
 *      Copyright 2006 Florian Sievers <florian@dopehouse.dyndns.org>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; version 2 of the License.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

#include <gpgme.h>

#include "gpg-crypter.h"
#include "crypto-operations.h"
#include "file-operations.h"
#include "edit-operations.h"

#include "callbacks.h"
#include "interface.h"
#include "support.h"

/* global variables */
gchar *plaintext_filename = NULL;
gchar *cipher_filename = NULL;

void
on_file_new_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget *textview_plaintext, *textview_cipher;
	GtkTextBuffer *buffer_plaintext, *buffer_cipher;

	textview_plaintext = lookup_widget(GTK_WIDGET(menuitem), "plaintext_textview");
	textview_cipher = lookup_widget(GTK_WIDGET(menuitem), "cipher_textview");

	/* get the textbuffers from the textview widgets */
	buffer_plaintext = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview_plaintext));
	buffer_cipher = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview_cipher));

	/* clear the textbuffers */
	gtk_text_buffer_set_text(GTK_TEXT_BUFFER(buffer_plaintext), "", -1);
	gtk_text_buffer_set_text(GTK_TEXT_BUFFER(buffer_cipher), "", -1);

	/* reset filenames to NULL */
	if(plaintext_filename != NULL)
	{
		g_free(plaintext_filename);
		plaintext_filename = NULL;
	}

	if(cipher_filename != NULL)
	{
		g_free(cipher_filename);
		cipher_filename = NULL;
	}
}


void
on_file_plaintext_open_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget *plaintext_textview;

	plaintext_textview = lookup_widget(GTK_WIDGET(menuitem), "plaintext_textview");
	plaintext_filename = open_file(plaintext_textview, plaintext_filename);
}


void
on_file_plaintext_save_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget *plaintext_textview;

	plaintext_textview = lookup_widget(GTK_WIDGET(menuitem), "plaintext_textview");
	plaintext_filename = save_file(plaintext_textview, plaintext_filename);
}


void
on_file_plaintext_save_as_activate     (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget *plaintext_textview;

	plaintext_textview = lookup_widget(GTK_WIDGET(menuitem), "plaintext_textview");
	plaintext_filename = save_as_file(plaintext_textview, plaintext_filename, TRUE);
}


void
on_file_cipher_open_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget *cipher_textview;

	cipher_textview = lookup_widget(GTK_WIDGET(menuitem), "cipher_textview");
	cipher_filename = open_file(cipher_textview, cipher_filename);
}


void
on_file_cipher_save_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget *cipher_textview;

	cipher_textview = lookup_widget(GTK_WIDGET(menuitem), "cipher_textview");
	cipher_filename = save_file(cipher_textview, cipher_filename);
}


void
on_file_cipher_save_as_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget *cipher_textview;

	cipher_textview = lookup_widget(GTK_WIDGET(menuitem), "cipher_textview");
	cipher_filename = save_as_file(cipher_textview, cipher_filename, TRUE);
}


void
on_file_quit_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	gtk_main_quit();
	return;
}


void
on_edit_cut_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	edit_cut_clipboard(GTK_WIDGET(menuitem), NULL);
}


void
on_edit_copy_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	edit_copy_clipboard(GTK_WIDGET(menuitem), NULL);
}


void
on_edit_paste_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	edit_paste_clipboard(GTK_WIDGET(menuitem), NULL);
}


void
on_edit_delete_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	edit_delete_clipboard(GTK_WIDGET(menuitem), NULL);
}


void
on_help_about_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget *dialog;

	dialog = create_aboutdialog();

	gtk_dialog_run(GTK_DIALOG(dialog));
	gtk_widget_destroy(dialog);
}


void
on_key_combobox_changed                (GtkComboBox     *combobox,
                                        gpointer         user_data)
{
	combo_select_key(GTK_WIDGET(combobox), user_data);
}


void
on_bt_encrypt_plaintext_clicked        (GtkButton       *button,
                                        gpointer         user_data)
{
	encrypt_buffer(GTK_WIDGET(button), app_data);
}


void
on_bt_clean_plaintext_clicked          (GtkButton       *button,
                                        gpointer         user_data)
{
	clear_plaintext_text_buffer(GTK_WIDGET(button), app_data);
}


void
on_bt_decrypt_cipher_clicked           (GtkButton       *button,
                                        gpointer         user_data)
{
	decrypt_buffer(GTK_WIDGET(button), app_data);
}


void
on_bt_clear_cipher_clicked             (GtkButton       *button,
                                        gpointer         user_data)
{
	clear_cipher_text_buffer(GTK_WIDGET(button), app_data);
}


void
on_chbt_cipher_file_ascii_armor_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data)
{
	change_chipher_file_asciimode(GTK_WIDGET(button), app_data);
}


void
on_plaintext_file_entry_changed        (GtkEditable     *editable,
                                        gpointer         user_data)
{
	plaintext_file_changed(GTK_WIDGET(editable), app_data);
}


void
on_bt_plaintext_file_select_clicked    (GtkButton       *button,
                                        gpointer         user_data)
{
	plaintext_file_selector(GTK_WIDGET(button), app_data);
}


void
on_cipher_file_entry_changed           (GtkEditable     *editable,
                                        gpointer         user_data)
{
	cipher_file_changed(GTK_WIDGET(editable), app_data);
}


void
on_bt_cipher_file_select_clicked       (GtkButton       *button,
                                        gpointer         user_data)
{
	cipher_file_selector(GTK_WIDGET(button), app_data);
}


void
on_bt_enctypt_plaintext_file_clicked   (GtkButton       *button,
                                        gpointer         user_data)
{
	encrypt_file(GTK_WIDGET(button), app_data);
}


void
on_bt_decrypt_cipher_file_clicked      (GtkButton       *button,
                                        gpointer         user_data)
{
	decrypt_file(GTK_WIDGET(button), app_data);
}


void
on_passphrase_callback_entry_activate  (GtkEntry        *entry,
                                        gpointer         user_data)
{
	/* response to enter-hit in the passphrase callback entryfield */
	GtkDialog *dialog;

	dialog = (GtkDialog *) lookup_widget(entry, "passphrase_callback_dialog");

	gtk_dialog_response(dialog, GTK_RESPONSE_OK);

	return;
}


void
on_bt_plaintext_copy_to_clipboard_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data)
{
	edit_copy_clipboard(GTK_WIDGET(button), "plaintext_textview");
}


void
on_bt_plaintext_insert_from_clipboard_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data)
{
	edit_paste_clipboard(GTK_WIDGET(button), "plaintext_textview");
}


void
on_bt_cipher_copy_to_clipboard_clicked (GtkButton       *button,
                                        gpointer         user_data)
{
	edit_copy_clipboard(GTK_WIDGET(button), "cipher_textview");
}


void
on_bt_cipher_insert_from_clipboard_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data)
{
	edit_paste_clipboard(GTK_WIDGET(button), "cipher_textview");
}

