/*
 *      error-dialogs.c
 *
 *      Copyright 2006 Florian Sievers <florian@dopehouse.dyndns.org>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; version 2 of the License.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include <stdio.h>
#include <stdlib.h>
#include <error.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gpgme.h>

#include "error-dialogs.h"

#include "support.h"

int error_dialog_with_errno(int errorno)
{
	printf("%s\n", strerror(errorno));
	return error_dialog_with_string(strerror(errorno));
}

int error_dialog_with_string(char *string)
{
	GtkWidget *error_dialog;
	error_dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "%s", g_locale_to_utf8(string, -1, NULL, NULL, NULL));
	gtk_dialog_run(GTK_DIALOG(error_dialog));
	gtk_widget_destroy(GTK_WIDGET(error_dialog));

	return 1;
}


int warn_dialog_with_errno(int errorno, char *question)
{
	printf("%s\n", strerror(errorno));
	return warn_dialog_with_string(strerror(errorno), question);
}

int warn_dialog_with_string(char *string, char *question)
{
	GtkWidget *error_dialog;
	gint result;
	int ret_val;

	error_dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, "%s\n%s", g_locale_to_utf8(string, -1, NULL, NULL, NULL), g_locale_to_utf8(question, -1, NULL, NULL, NULL));
	result = gtk_dialog_run(GTK_DIALOG(error_dialog));
	switch(result)
	{
		case GTK_RESPONSE_YES:
			ret_val = 0;
			break;
		case GTK_RESPONSE_NO:
			ret_val = 1;
			break;
		default:
			break;
	}

	gtk_widget_destroy(GTK_WIDGET(error_dialog));

	return ret_val;
}
